Learn R Programming

rrefine (version 2.1.0)

lateformeeting: a "dirty" data set to demonstrate rrefine features

Description

This data is a simulated collection of dates, days of the week, numbers of hours slept and indicators of whether or not the subject was on time for work. All observations appearing in this data set are fictitious, and any resemblance to actual arrival times for work is purely coincidental.

Usage

lateformeeting

Arguments

Format

A data frame with 63 rows and 4 variables

  • theDate date of observation in varying formats

  • what.day.whas.it day of the week in varying formats

  • sleephours number of hours slept

  • was.i.on.time.for.work indicator of on-time arrival to work

Examples

Run this code
head(lateformeeting)

Run the code above in your browser using DataLab