Learn R Programming

rrefine (version 2.1.0)

refine_project_summary: Get project summary data

Description

This function retrieves high-level project summary data (such as id, name, date created, date modified, description, and row count) from all projects in the OpenRefine instance. Internally this function uses refine_metadata to pull information from project metadata.

Usage

refine_project_summary(...)

Value

A data.frame with observations containting high-level summary metadata for all projects in the OpenRefine instance. Columns include: project id ("id"), project name ("name"), project description ("description"), count of number of project rows ("rowCount"), date created ("created"), and date modified ("modified").

Arguments

...

Additional parameters to be inherited by refine_path; allows users to specify host and port arguments if the OpenRefine instance is running at a location other than http://127.0.0.1:3333

References

https://docs.openrefine.org/technical-reference/openrefine-api#get-all-projects-metadata

Examples

Run this code
if (FALSE) {
refine_project_summary()
}

Run the code above in your browser using DataLab