Learn R Programming

rrefine (version 2.1.0)

refine_rename_column: Rename a column in OpenRefine project

Description

This function allows users to rename an existing column in an OpenRefine project via an API query to /command/core/apply-operations and the core/column-rename operation.

Usage

refine_rename_column(
  original_name,
  new_name,
  project.name = NULL,
  project.id = NULL,
  verbose = FALSE,
  validate = TRUE,
  ...
)

Value

Operates as a side-effect passing operations to the OpenRefine instance. However, if verbose=TRUE then the function will return an object of the class "response".

Arguments

original_name

Original name for the column

new_name

New name for the column

project.name

Name of project

project.id

Unique identifier for project

verbose

Logical specifying whether or not query result should be printed; default is FALSE

validate

Logical as to whether or not the operation should validate parameters against existing data in project; default is TRUE

...

Additional parameters to be inherited by refine_path; allows users to specify host and port arguments if the OpenRefine instance is running at a location other than http://127.0.0.1:3333

Examples

Run this code

if (FALSE) {
fp <- system.file("extdata", "lateformeeting.csv", package = "rrefine")
refine_upload(fp, project.name = "lfm")
refine_rename_column("what day whas it", "what_day_was_it", project.name = "lfm")
}


Run the code above in your browser using DataLab